# django-importo

NOTE: This is still very much a work-in-progress. Don't expect anything to work yet!

Management commands and utilities for importing large amounts of data from various sources. The app is tested for compatibility with:
- Django >= 3.1
- Wagtail >= 2.12

## Get started

1. Install this app with `pip install django-importo`
2. Add `importo` to your `INSTALLED_APPS`
